@@ -21,7 +21,7 @@ from .lib.helpers.dupedict import DupeDict, JSON
 from .lib.helpers.paths import secure_filename
 
 __author__ = 'Anton Hvornum'
-__version__ = '0.0.18'
+__version__ = '0.0.20'
 __description__ = "Our KVM solution, clulstered and self hosted"
 
 # TODO: https://stackoverflow.com/questions/15889621/sphinx-how-to-exclude-imports-in-automodule
@@ -37,6 +37,8 @@ parser.add_argument("--auth-schema", default="Keycloak", nargs="?", help="Which
 
 # Cluster arguments
 parser.add_argument("--cluster", default=False, action="store_true", help="Enable API functionality")
+parser.add_argument("--cluster-addr", default="127.0.0.1", nargs="?", help="Which address to listen on, set to '' (empty) to listen on all addresses.", type=str)
+parser.add_argument("--cluster-port", default=8050, nargs="?", help="Which port to listen on for cluster communication.", type=int)
 parser.add_argument("--cluster-nodes", default="[]", nargs="?", help="A JSON list of known nodes (node sharing will occur, so one is minimum to enable) using the format: [{\"ip\": port}, {\"ip\": port}]", type=str)
 
 # KVM helper arguments for creating machines
@@ -48,7 +50,7 @@ parser.add_argument("--harddrives", default=None, nargs="?", help="A comma-separ
 parser.add_argument("--cdroms", default=None, nargs="?", help="A comma-separated list of ISO/cdrom images using the format 'image.iso[,image2.iso]'", type=str)
 parser.add_argument("--no-namespace", default=False, action="store_true", help="This will disable namespace-creation for the machine and by default for network intrastructure")
 parser.add_argument("--graphics", default=False, action="store_true", help="This will turn on default graphics output (gtk) for qemu, the oposit of headless (default)")
-parser.add_argument("--namespace", default=None, nargs="?", help="Defaults to using the machine name", type=str)
+parser.add_argument("--namespace", default=None, nargs="?", help="Tells --machine-name or --new-netdev which namespace the machine or interface should be in.", type=str)
 parser.add_argument("--network", default=None, nargs="?", help="Defaults to using NAT. The syntax is a bit complex, refer to the man pages for information.", type=str)
 parser.add_argument("--uefi-vars", default='/usr/share/ovmf/x64/OVMF_VARS.fd', nargs="?", help="Defines the path to the EFI variables (defaults to using find -iname for the vars)", type=str)
 parser.add_argument("--uefi-code", default='/usr/share/ovmf/x64/OVMF_CODE.fd', nargs="?", help="Defines the path to the EFI code (defaults to using find -iname for the code)", type=str)
@@ -62,6 +64,13 @@ parser.add_argument("--debug", default=False, action="store_true", help="Turns o
 parser.add_argument("--serial", default=None, nargs="?", help="Will redirect monitor and stdio serial device to a unix socket and a log-file for easier log analytics")
 parser.add_argument("--bring-online", nargs="?", default="", help="Takes a path of a ourkvm .cfg and takes any post boot network interfaces online (tap interfaces).")
 parser.add_argument("--graceful-shutdown", nargs="?", default=30, help="Sets the grace period in seconds before a forceful shutdown is done with --stop", type=int)
+parser.add_argument("--add-netdev", nargs="?", default=None, help="Adds a netdev interface to a running or turned off virtual machine", type=str)
+parser.add_argument("--nocreate", default=False, action="store_true", help="Disables creation of the new --add-netdev interface. Defaults to create it.")
+parser.add_argument("--network-id", nargs="?", default=None, help="Adds optional network id to --add-netdev interface. Defaults to current-ids+1", type=str)
+parser.add_argument("--mac", nargs="?", default=None, help="Adds optional MAC address to new --add-netdev. Defaults to auto-generated one.", type=str)
+parser.add_argument("--bridge", nargs="?", default=None, help="Adds optional bridge attachment to the new --add-netdev. Defaults to None.", type=str)
+parser.add_argument("--snapshot", default=False, action="store_true", help="Snapshots a --machine-name and all of it's resources (running or hybernated)")
+parser.add_argument("--norecurse", default=False, action="store_true", help="Blocks --snapshot from recursing down in to namespaces (used internally mainly)")
 
 # ourkvm agent arguments
 parser.add_argument("--report-health", default=False, action="store_true", help="Reports this machines health to the --health-server")
@@ -93,7 +102,8 @@ from .lib.networking import (
 	get_all_mac_addresses_in_use,
 	get_namespaces,
 	curate_interfaces,
-	ifup
+	ifup,
+	InterfaceStruct
 )
 from .lib.qemu import (
 	qemu_img,
@@ -101,24 +111,33 @@ from .lib.qemu import (
 	verify_qemu_resources,
 	write_qemu_service_file,
 	get_machine_disk_information,
-	get_diskimage_information
+	get_diskimage_information,
+	get_harddrives,
+	get_machine_status,
+	QMP
 )
 from .lib.qemu.environment import (
 	load_environment,
 	dismantle_environment,
 	load_conf,
 	load_network_cards_from_env,
-	get_network_cards_from_env
+	get_network_cards_from_env,
+	get_network_card_info_from_env
 )
+from .lib.qemu.snapshots import take_snapshot
 
 # --dluster-nodes implicitly enables --cluster
 if storage['arguments'].cluster_nodes:
 	args.cluster = True
 
 if args.cluster or 'sphinx' in sys.modules:
-	from .lib.cluster import ClusterServer
+	from .cluster import SimplifiedServerSocket as SimplifiedServerSocket
+	from .cluster import ClusterServer as ClusterServer
 
 	if 'sphinx' not in sys.modules:
-		handle = ClusterServer()
-		while handle.poll() is True:
-			pass
\ No newline at end of file
+		cluster = ClusterServer()
+		cluster.listen()
+
+		while True:
+			for fileno, data in cluster.recv():
+				cluster.process(fileno, data)
\ No newline at end of file
