@@ -1,9 +1,15 @@
 from .networking import epoll, EPOLLIN, EPOLLHUP
 from .networking import generate_mac
+from .networking import get_all_interfaces
+from .networking import curate_interfaces
+from .networking import get_all_mac_addresses_in_use
+from .networking import get_bridge_interfaces
+from .networking import InterfaceStruct
 from .qemu.environment import load_network_cards_from_env as load_network_cards_from_env
 from .qemu.environment import load_conf as load_conf
 from .qemu.environment import load_environment as load_environment
 from .qemu.environment import dismantle_environment as dismantle_environment
+from .qemu.snapshots import take_snapshot as take_snapshot
 from .helpers import DupeDict as DupeDict
 from .helpers import JsonEncoder as JsonEncoder
 from .helpers import JSON as JSON
