@@ -19,6 +19,8 @@ from .interfaces import generate_mac as generate_mac
 from .interfaces import get_bridge_interfaces as get_bridge_interfaces
 from .interfaces import get_all_mac_addresses_in_use as get_all_mac_addresses_in_use
 from .interfaces import curate_interfaces as curate_interfaces
+from .interfaces import get_all_interfaces as get_all_interfaces
+from .structs import InterfaceStruct as InterfaceStruct
 
 __all__ = [
 	"epoll",
@@ -41,5 +43,7 @@ __all__ = [
 	"get_bridge_interfaces",
 	"get_all_mac_addresses_in_use",
 	"get_namespaces",
-	"curate_interfaces"
+	"curate_interfaces",
+	"get_all_interfaces",
+	"InterfaceStruct"
 ]
\ No newline at end of file
