@@ -1,11 +1,13 @@
 import json
 import pathlib
+import glob
 from typing import Dict, Any, List
 
-from ..networking import load_network_info, unload_network_info, get_namespace_info, add_namespace, del_namespace, generate_mac, curate_interfaces
+from .qemu import get_machine_disk_information
+from ..networking import InterfaceStruct, load_network_info, unload_network_info, get_namespace_info, add_namespace, del_namespace, generate_mac, curate_interfaces
 from ..helpers.exceptions import NamespaceNotFound, ConfigurationError, NamespaceError
 
-def load_conf(config :str) -> Dict[str, Any]:
+def load_conf(config :pathlib.Path) -> Dict[str, Any]:
 	"""
 	This function loads a machine configuration (.cfg) and
 	converts it to a dictionary.
@@ -34,7 +36,7 @@ def load_environment(config :str) -> None:
 	before the interfaces can be brought up. See --bring-online flag
 	in the CLI Tool for more information.
 	"""
-	configuration = load_conf(config)
+	configuration = load_conf(pathlib.Path(config).expanduser().absolute())
 
 	if namespace := configuration.get('namespace'):
 		try:
@@ -43,7 +45,7 @@ def load_environment(config :str) -> None:
 			add_namespace(namespace)
 
 	if interfaces := configuration.get('interfaces'):
-		load_network_info(interfaces=curate_interfaces(interfaces, namespace))
+		load_network_info(interfaces=curate_interfaces([InterfaceStruct(**interface) for interface in interfaces], namespace))
 
 
 def dismantle_environment(config :str) -> None:
@@ -51,7 +53,7 @@ def dismantle_environment(config :str) -> None:
 	Loads a machine configuration and dismantles the environment.
 	This is essentially like load_environment() but in reverse.
 	"""
-	configuration = load_conf(config)
+	configuration = load_conf(pathlib.Path(config).expanduser().absolute())
 
 	if configuration.get('interfaces'):
 		unload_network_info(interfaces=configuration['interfaces'])
@@ -70,7 +72,7 @@ def load_network_cards_from_env(config :str) -> str:
 	string of the network definitions. This is what --qemu-string
 	is calling to achieve the network part of the string.
 	"""
-	configuration = load_conf(config)
+	configuration = load_conf(pathlib.Path(config).expanduser().absolute())
 
 	result = ''
 
@@ -85,7 +87,7 @@ def load_network_cards_from_env(config :str) -> str:
 
 				previous_macs.append(mac)
 				
-				result += f" -device virtio-net-pci,mac={mac},id=network{network_id},netdev=network{network_id}.{interface_on_network},status=on,bus=pcie.0" # ,bootindex=2
+				result += f" -device virtio-net-pci,mac={mac},id=network{network_id},netdev=network{network_id}.{interface_on_network},status=on,bus=port9-0" # ,bootindex=2
 				result += f" -netdev {interface['type']},ifname={interface['name']},id=network{network_id}.{interface_on_network},script=no,downscript=no"
 				interface_on_network += 1
 
@@ -99,7 +101,7 @@ def get_network_cards_from_env(config :str) -> Dict[str, Any]:
 	Loads a machine configuration and returns a flag dictionary structure.
 	The contents of the dict is ``{"ifname": "namespace name"}`` (or ``None`` in value if no namespace).
 	"""
-	configuration = load_conf(config)
+	configuration = load_conf(pathlib.Path(config).expanduser().absolute())
 
 	result = {}
 	if interfaces := configuration.get('interfaces'):
@@ -109,4 +111,27 @@ def get_network_cards_from_env(config :str) -> Dict[str, Any]:
 			if interface.get('attach'):
 				result[interface.get('name')] = interface.get('namespace')
 
-	return result
\ No newline at end of file
+	return result
+
+
+def get_network_card_info_from_env(config :pathlib.Path) -> List[InterfaceStruct]:
+	configuration = load_conf(config)
+
+	if interfaces := configuration.get('interfaces'):
+		return curate_interfaces(interfaces, configuration.get('namespace'))
+
+	return []
+
+def get_harddrives(
+	include_outside_of_cfg :bool = True,
+	include_inside_of_cfg :bool = True) -> List[Dict[str, Any]]:
+
+	harddrives = []
+	if include_inside_of_cfg:
+		for configuration in glob.glob('/etc/qemu.d/*.cfg'):
+			harddrives.append({
+				"machine_id": pathlib.Path(configuration).stem,
+				"harddrives": get_machine_disk_information(pathlib.Path(configuration).stem)
+			})
+
+	return harddrives
\ No newline at end of file
